@@ -1,11 +1,68 @@
+/*
+ * gitg-repository-dialog.h
+ * This file is part of gitg - git repository viewer
+ *
+ * Copyright (C) 2009 - Jesse van den Kieboom
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <glib/gi18n.h>
 
 #include <stdlib.h>
+#include <libgitg/gitg-config.h>
+#include <libgitg/gitg-shell.h>
 
 #include "gitg-repository-dialog.h"
 #include "gitg-utils.h"
-#include "gitg-config.h"
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#ifdef BUILD_SPINNER
 #include "gitg-spinner.h"
+#endif
+
+void on_button_fetch_remote_clicked (GtkButton *button,
+                                     GitgRepositoryDialog *dialog);
+
+void on_button_remove_remote_clicked (GtkButton *button,
+                                      GitgRepositoryDialog *dialog);
+
+void on_button_add_remote_clicked (GtkButton *button,
+                                   GitgRepositoryDialog *dialog);
+
+gboolean on_entry_repository_user_name_focus_out_event (GtkEntry *entry,
+                                                        GdkEventFocus *focus,
+                                                        GitgRepositoryDialog *dialog);
+
+gboolean on_entry_repository_user_email_focus_out_event (GtkEntry *entry,
+                                                         GdkEventFocus *focus,
+                                                         GitgRepositoryDialog *dialog);
+
+void on_remote_name_edited (GtkCellRendererText *renderer,
+                            gchar *path,
+                            gchar *new_text,
+                            GitgRepositoryDialog *dialog);
+
+void on_remote_url_edited (GtkCellRendererText *renderer,
+                           gchar *path,
+                           gchar *new_text,
+                           GitgRepositoryDialog *dialog);
 
 #define GITG_REPOSITORY_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GITG_TYPE_REPOSITORY_DIALOG, GitgRepositoryDialogPrivate))
 
@@ -15,7 +72,9 @@ enum
 {
 	COLUMN_NAME,
 	COLUMN_URL,
-	COLUMN_FETCH
+	COLUMN_FETCH,
+	COLUMN_PULSE,
+	COLUMN_SPINNER
 };
 
 struct _GitgRepositoryDialogPrivate
@@ -42,19 +101,19 @@ G_DEFINE_TYPE (GitgRepositoryDialog, gitg_repository_dialog, GTK_TYPE_DIALOG)
 typedef struct
 {
 	GitgRepositoryDialog *dialog;
-	GitgRunner *runner;
+	GitgShell *shell;
 	GtkTreeRowReference *reference;
+
+#ifdef BUILD_SPINNER
 	GitgSpinner *spinner;
+#else
+	guint pulse_id;
+#endif
 } FetchInfo;
 
 static void
 fetch_cleanup (FetchInfo *info)
 {
-	if (info->spinner)
-	{
-		g_object_unref (info->spinner);
-	}
-
 	info->dialog->priv->fetchers = g_list_remove (info->dialog->priv->fetchers, info);
 
 	if (gtk_tree_row_reference_valid (info->reference))
@@ -66,16 +125,32 @@ fetch_cleanup (FetchInfo *info)
 		                         &iter,
 		                         path);
 
+#ifdef BUILD_SPINNER
 		gtk_list_store_set (info->dialog->priv->list_store_remotes,
 		                    &iter,
-		                    COLUMN_FETCH, NULL,
+		                    COLUMN_SPINNER, NULL,
+		                    -1);
+#endif
+
+		gtk_list_store_set (info->dialog->priv->list_store_remotes,
+		                    &iter,
+		                    COLUMN_FETCH, FALSE,
 		                    -1);
 
 		gtk_tree_path_free (path);
 	}
 
+#ifdef BUILD_SPINNER
+	if (info->spinner)
+	{
+		g_object_unref (info->spinner);
+	}
+#else
+	g_source_remove (info->pulse_id);
+#endif
+
 	gtk_tree_row_reference_free (info->reference);
-	g_object_unref (info->runner);
+	g_object_unref (info->shell);
 
 	g_slice_free (FetchInfo, info);
 }
@@ -100,11 +175,11 @@ gitg_repository_dialog_finalize (GObject *object)
 
 	for (item = copy; item; item = g_list_next (item))
 	{
-		gitg_runner_cancel (((FetchInfo *)item->data)->runner);
+		gitg_io_cancel (GITG_IO (((FetchInfo *)item->data)->shell));
 	}
 
 	g_list_free (copy);
-	g_list_foreach (dialog->priv->fetchers, (GFunc)fetch_cleanup, NULL);
+	g_list_free (dialog->priv->fetchers);
 
 	G_OBJECT_CLASS (gitg_repository_dialog_parent_class)->finalize (object);
 }
@@ -147,19 +222,16 @@ update_fetch (GitgRepositoryDialog *dialog)
 	{
 		GtkTreePath *path = (GtkTreePath *)item->data;
 		GtkTreeIter iter;
-		GdkPixbuf *fetch;
 
 		gtk_tree_model_get_iter (model, &iter, path);
+
+		gboolean fetch;
 		gtk_tree_model_get (model, &iter, COLUMN_FETCH, &fetch, -1);
 
 		if (!fetch)
 		{
 			show_fetch = TRUE;
 		}
-		else
-		{
-			g_object_unref (fetch);
-		}
 	}
 
 	if (!rows)
@@ -208,14 +280,17 @@ add_remote (GitgRepositoryDialog *dialog, gchar const *name, gchar const *url, G
 	GtkTreeIter it;
 
 	gtk_list_store_append (dialog->priv->list_store_remotes, iter ? iter : &it);
-	gtk_list_store_set (dialog->priv->list_store_remotes, 
+	gtk_list_store_set (dialog->priv->list_store_remotes,
 	                    iter ? iter : &it,
 	                    COLUMN_NAME, name,
 	                    COLUMN_URL, url,
-	                    COLUMN_FETCH, NULL,
+	                    COLUMN_FETCH, FALSE,
+	                    COLUMN_PULSE, 0,
+	                    COLUMN_SPINNER, NULL,
 	                    -1);
 }
 
+#ifdef BUILD_SPINNER
 static void
 on_spinner_frame (GitgSpinner *spinner, GdkPixbuf *pixbuf, FetchInfo *info)
 {
@@ -228,26 +303,92 @@ on_spinner_frame (GitgSpinner *spinner, GdkPixbuf *pixbuf, FetchInfo *info)
 
 	gtk_list_store_set (info->dialog->priv->list_store_remotes,
 	                    &iter,
-	                    COLUMN_FETCH, pixbuf,
+	                    COLUMN_SPINNER, pixbuf,
 	                    -1);
 
 	gtk_tree_path_free (path);
 }
+#else
+static gboolean
+pulse_row (FetchInfo *info)
+{
+	gint pulse;
+	gboolean fetch;
+	GtkTreeIter iter;
+	GtkTreePath *path = gtk_tree_row_reference_get_path (info->reference);
+
+	gtk_tree_model_get_iter (GTK_TREE_MODEL (info->dialog->priv->list_store_remotes),
+	                         &iter,
+	                         path);
+
+	gtk_tree_model_get (GTK_TREE_MODEL (info->dialog->priv->list_store_remotes),
+	                    &iter,
+	                    COLUMN_FETCH, &fetch,
+	                    COLUMN_PULSE, &pulse,
+	                    -1);
+
+	if (fetch)
+	{
+		gtk_list_store_set (info->dialog->priv->list_store_remotes,
+			            &iter,
+			            COLUMN_PULSE, pulse + 1,
+			            -1);
+	}
+
+	gtk_tree_path_free (path);
+
+	return fetch;
+}
+#endif
 
 static void
-on_fetch_begin_loading (GitgRunner *runner, FetchInfo *info)
+on_fetch_begin_loading (GitgShell *shell, FetchInfo *info)
 {
+	GtkTreeIter iter;
+	GtkTreePath *path = gtk_tree_row_reference_get_path (info->reference);
+
+	gtk_tree_model_get_iter (GTK_TREE_MODEL (info->dialog->priv->list_store_remotes),
+	                         &iter,
+	                         path);
+
+	gtk_list_store_set (info->dialog->priv->list_store_remotes,
+	                    &iter,
+	                    COLUMN_FETCH, TRUE,
+	                    -1);
+
+#ifdef BUILD_SPINNER
 	info->spinner = gitg_spinner_new (GTK_ICON_SIZE_MENU);
 	gitg_spinner_set_screen (info->spinner, gtk_widget_get_screen (GTK_WIDGET (info->dialog)));
 
 	g_signal_connect (info->spinner, "frame", G_CALLBACK (on_spinner_frame), info);
 	gitg_spinner_start (info->spinner);
+#else
+	GtkStyle *style = gtk_widget_get_style (GTK_WIDGET (info->dialog->priv->tree_view_remotes));
 
+	GValue cycle_duration = {0,};
+	GValue num_steps = {0,};
+
+	g_value_init (&cycle_duration, G_TYPE_UINT);
+	g_value_init (&num_steps, G_TYPE_UINT);
+
+	gtk_style_get_style_property (style, GTK_TYPE_SPINNER, "num-steps", &num_steps);
+	gtk_style_get_style_property (style, GTK_TYPE_SPINNER, "cycle-duration", &cycle_duration);
+
+	info->pulse_id = g_timeout_add (g_value_get_uint (&cycle_duration) /
+	                                g_value_get_uint (&num_steps),
+	                                (GSourceFunc)pulse_row,
+	                                info);
+
+	g_value_unset (&cycle_duration);
+	g_value_unset (&num_steps);
+#endif
+
+	gtk_tree_path_free (path);
 	update_fetch (info->dialog);
 }
 
 static void
-on_fetch_end_loading (GitgRunner *runner, gboolean cancelled, FetchInfo *info)
+on_fetch_end_loading (GitgShell *shell, gboolean cancelled, FetchInfo *info)
 {
 	if (cancelled || !gtk_tree_row_reference_valid (info->reference))
 	{
@@ -266,7 +407,7 @@ on_fetch_end_loading (GitgRunner *runner, gboolean cancelled, FetchInfo *info)
 static void
 fetch_remote (GitgRepositoryDialog *dialog, GtkTreeIter *iter)
 {
-	GitgRunner *runner = gitg_runner_new (1000);
+	GitgShell *shell = gitg_shell_new (1000);
 	FetchInfo *info = g_slice_new0 (FetchInfo);
 	GtkTreeModel *model = GTK_TREE_MODEL (dialog->priv->list_store_remotes);
 
@@ -274,17 +415,17 @@ fetch_remote (GitgRepositoryDialog *dialog, GtkTreeIter *iter)
 
 	info->dialog = dialog;
 	info->reference = gtk_tree_row_reference_new (model, path);
-	info->runner = runner;
+	info->shell = shell;
 
-	gtk_tree_path_free (path); 
+	gtk_tree_path_free (path);
 
-	g_signal_connect (runner, 
-	                  "begin-loading", 
+	g_signal_connect (shell,
+	                  "begin",
 	                  G_CALLBACK (on_fetch_begin_loading),
 	                  info);
 
-	g_signal_connect (runner,
-	                  "end-loading",
+	g_signal_connect (shell,
+	                  "end",
 	                  G_CALLBACK (on_fetch_end_loading),
 	                  info);
 
@@ -293,12 +434,12 @@ fetch_remote (GitgRepositoryDialog *dialog, GtkTreeIter *iter)
 	gchar *name;
 	gtk_tree_model_get (model, iter, COLUMN_NAME, &name, -1);
 
-	gitg_repository_run_commandv (dialog->priv->repository,
-	                              runner,
-	                              NULL,
-	                              "fetch",
-	                              name,
-	                              NULL);
+	gitg_shell_run (shell,
+	                gitg_command_new (dialog->priv->repository,
+	                                   "fetch",
+	                                   name,
+	                                   NULL),
+	                NULL);
 
 	g_free (name);
 }
@@ -312,7 +453,9 @@ on_selection_changed (GtkTreeSelection *selection, GitgRepositoryDialog *dialog)
 static void
 init_remotes(GitgRepositoryDialog *dialog)
 {
-	gchar *ret = gitg_config_get_value_regex (dialog->priv->config, "remote\\..*\\.url");
+	gchar *ret = gitg_config_get_value_regex (dialog->priv->config,
+	                                          "remote\\..*\\.url",
+	                                          NULL);
 
 	if (!ret)
 	{
@@ -373,16 +516,41 @@ init_properties(GitgRepositoryDialog *dialog)
 	init_remotes(dialog);
 }
 
+#ifndef BUILD_SPINNER
 static void
-fetch_data_cb (GtkTreeViewColumn    *column,
-               GtkCellRenderer      *cell,
-               GtkTreeModel         *model,
-               GtkTreeIter          *iter,
-               GitgRepositoryDialog *dialog)
+fetch_data_spinner_cb (GtkTreeViewColumn    *column,
+                       GtkCellRenderer      *cell,
+                       GtkTreeModel         *model,
+                       GtkTreeIter          *iter,
+                       GitgRepositoryDialog *dialog)
 {
+	gboolean fetch;
+	guint pulse;
+
+	gtk_tree_model_get (model, iter,
+	                    COLUMN_FETCH, &fetch,
+	                    COLUMN_PULSE, &pulse,
+	                    -1);
+
+	g_object_set (G_OBJECT (cell),
+	              "active", fetch,
+	              "visible", fetch,
+	              "pulse", pulse,
+	              NULL);
+}
+#endif
+
+static void
+fetch_data_icon_cb (GtkTreeViewColumn    *column,
+                    GtkCellRenderer      *cell,
+                    GtkTreeModel         *model,
+                    GtkTreeIter          *iter,
+                    GitgRepositoryDialog *dialog)
+{
+#ifdef BUILD_SPINNER
 	GdkPixbuf *fetch;
 
-	gtk_tree_model_get (model, iter, COLUMN_FETCH, &fetch, -1);
+	gtk_tree_model_get (model, iter, COLUMN_SPINNER, &fetch, -1);
 
 	if (fetch)
 	{
@@ -391,12 +559,20 @@ fetch_data_cb (GtkTreeViewColumn    *column,
 	}
 	else
 	{
-		g_object_set (cell, 
-		              "stock-id", GTK_STOCK_NETWORK, 
-		              NULL);
+		g_object_set (cell, "stock-id", GTK_STOCK_NETWORK, NULL);
 	}
+#else
+	gboolean fetch;
+
+	gtk_tree_model_get (model, iter, COLUMN_FETCH, &fetch, -1);
+
+	g_object_set (G_OBJECT (cell),
+	              "visible", !fetch,
+	              NULL);
+#endif
 }
 
+
 static void
 create_repository_dialog (GitgWindow *window)
 {
@@ -425,22 +601,39 @@ create_repository_dialog (GitgWindow *window)
 	repository_dialog->priv->button_fetch_remote = GTK_BUTTON(gtk_builder_get_object(b, "button_fetch_remote"));
 	repository_dialog->priv->image_fetch_remote = GTK_IMAGE(gtk_builder_get_object(b, "image_fetch_remote"));
 
-	GObject *column = gtk_builder_get_object(b, "tree_view_remotes_column_name");
-	GObject *renderer = gtk_builder_get_object(b, "tree_view_remotes_renderer_icon");
+	GtkTreeViewColumn *column = GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (b, "tree_view_remotes_column_name"));
 
-	gtk_tree_view_column_set_cell_data_func (GTK_TREE_VIEW_COLUMN (column),
-	                                         GTK_CELL_RENDERER (renderer),
-	                                         (GtkTreeCellDataFunc)fetch_data_cb,
+#ifndef BUILD_SPINNER
+	GtkCellRenderer *spinner_renderer = gtk_cell_renderer_spinner_new ();
+	g_object_set (spinner_renderer, "visible", FALSE, NULL);
+
+	gtk_tree_view_column_pack_start (column, spinner_renderer, FALSE);
+	gtk_cell_layout_reorder (GTK_CELL_LAYOUT (column), spinner_renderer, 1);
+
+	gtk_tree_view_column_set_cell_data_func (column,
+	                                         spinner_renderer,
+	                                         (GtkTreeCellDataFunc)fetch_data_spinner_cb,
+	                                         repository_dialog,
+	                                         NULL);
+#endif
+
+	GtkCellRenderer *icon_renderer = GTK_CELL_RENDERER (gtk_builder_get_object (b, "tree_view_remotes_renderer_icon"));
+	gtk_tree_view_column_set_cell_data_func (column,
+	                                         icon_renderer,
+	                                         (GtkTreeCellDataFunc)fetch_data_icon_cb,
 	                                         repository_dialog,
 	                                         NULL);
 
 	gtk_builder_connect_signals(b, repository_dialog);
 	g_object_unref (b);
 
-	gchar *basename = g_path_get_basename(gitg_repository_get_path(repository));
-	gchar *title = g_strdup_printf("%s - %s", _("Properties"), basename);
+	GFile *work_tree = gitg_repository_get_work_tree (repository);
+	gchar *basename = g_file_get_basename (work_tree);
+	g_object_unref (work_tree);
 
+	gchar *title = g_strdup_printf("%s - %s", _("Properties"), basename);
 	gtk_window_set_title(GTK_WINDOW(repository_dialog), title);
+
 	g_free (title);
 	g_free (basename);
 
@@ -450,10 +643,12 @@ create_repository_dialog (GitgWindow *window)
 }
 
 GitgRepositoryDialog *
-gitg_repository_dialog_present(GitgWindow *window)
+gitg_repository_dialog_present (GitgWindow *window)
 {
 	if (!repository_dialog)
+	{
 		create_repository_dialog(window);
+	}
 
 	gtk_window_set_transient_for(GTK_WINDOW(repository_dialog), GTK_WINDOW (window));
 	gtk_window_present(GTK_WINDOW(repository_dialog));
@@ -462,7 +657,7 @@ gitg_repository_dialog_present(GitgWindow *window)
 }
 
 void
-gitg_repository_dialog_close ()
+gitg_repository_dialog_close (void)
 {
 	if (repository_dialog)
 	{
@@ -471,7 +666,8 @@ gitg_repository_dialog_close ()
 }
 
 static void
-fetch_remote_cancel (GitgRepositoryDialog *dialog, GtkTreeIter *iter)
+fetch_remote_cancel (GitgRepositoryDialog *dialog,
+                     GtkTreeIter          *iter)
 {
 	GList *item;
 	GtkTreePath *orig;
@@ -489,7 +685,7 @@ fetch_remote_cancel (GitgRepositoryDialog *dialog, GtkTreeIter *iter)
 
 		if (equal)
 		{
-			gitg_runner_cancel (info->runner);
+			gitg_io_cancel (GITG_IO (info->shell));
 			break;
 		}
 	}
@@ -498,7 +694,8 @@ fetch_remote_cancel (GitgRepositoryDialog *dialog, GtkTreeIter *iter)
 }
 
 void
-on_button_fetch_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
+on_button_fetch_remote_clicked (GtkButton            *button,
+                                GitgRepositoryDialog *dialog)
 {
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
@@ -512,7 +709,7 @@ on_button_fetch_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
 	{
 		GtkTreePath *path = (GtkTreePath *)item->data;
 		GtkTreeIter iter;
-		GdkPixbuf *fetch;
+		gboolean fetch;
 
 		gtk_tree_model_get_iter (model, &iter, path);
 		gtk_tree_model_get (model, &iter, COLUMN_FETCH, &fetch, -1);
@@ -526,11 +723,6 @@ on_button_fetch_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
 			fetch_remote_cancel (dialog, &iter);
 		}
 
-		if (fetch)
-		{
-			g_object_unref (fetch);
-		}
-
 		gtk_tree_path_free (path);
 	}
 
@@ -545,16 +737,17 @@ on_button_fetch_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
 static gboolean
 remove_remote (GitgRepositoryDialog *dialog, gchar const *name)
 {
-	return gitg_repository_commandv (dialog->priv->repository,
-	                                 NULL,
-	                                 "remote",
-	                                 "rm",
-	                                 name,
-	                                 NULL);
+	return gitg_shell_run_sync (gitg_command_new (dialog->priv->repository,
+	                                               "remote",
+	                                               "rm",
+	                                               name,
+	                                               NULL),
+	                            NULL);
 }
 
 void
-on_button_remove_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
+on_button_remove_remote_clicked (GtkButton *button,
+                                 GitgRepositoryDialog *dialog)
 {
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
@@ -604,7 +797,8 @@ on_button_remove_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog
 }
 
 void
-on_button_add_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
+on_button_add_remote_clicked (GtkButton *button,
+                              GitgRepositoryDialog *dialog)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL (dialog->priv->list_store_remotes);
 	GtkTreeIter iter;
@@ -635,7 +829,13 @@ on_button_add_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
 	gchar *name = g_strdup_printf ("remote%d", num + 1);
 	gchar const url[] = "git://example.com/repository.git";
 
-	if (gitg_repository_commandv (dialog->priv->repository, NULL, "remote", "add", name, url, NULL))
+	if (gitg_shell_run_sync (gitg_command_new (dialog->priv->repository,
+	                                            "remote",
+	                                            "add",
+	                                            name,
+	                                            url,
+	                                            NULL),
+	                         NULL))
 	{
 		GtkTreeIter iter;
 		GtkTreePath *path;
@@ -656,7 +856,9 @@ on_button_add_remote_clicked (GtkButton *button, GitgRepositoryDialog *dialog)
 }
 
 gboolean
-on_entry_repository_user_name_focus_out_event (GtkEntry *entry, GdkEventFocus *focus, GitgRepositoryDialog *dialog)
+on_entry_repository_user_name_focus_out_event (GtkEntry *entry,
+                                               GdkEventFocus *focus,
+                                               GitgRepositoryDialog *dialog)
 {
 	gchar const *text;
 
@@ -667,7 +869,9 @@ on_entry_repository_user_name_focus_out_event (GtkEntry *entry, GdkEventFocus *f
 }
 
 gboolean
-on_entry_repository_user_email_focus_out_event (GtkEntry *entry, GdkEventFocus *focus, GitgRepositoryDialog *dialog)
+on_entry_repository_user_email_focus_out_event (GtkEntry *entry,
+                                                GdkEventFocus *focus,
+                                                GitgRepositoryDialog *dialog)
 {
 	gchar const *text;
 
@@ -678,7 +882,10 @@ on_entry_repository_user_email_focus_out_event (GtkEntry *entry, GdkEventFocus *
 }
 
 void
-on_remote_name_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_text, GitgRepositoryDialog *dialog)
+on_remote_name_edited (GtkCellRendererText *renderer,
+                       gchar *path,
+                       gchar *new_text,
+                       GitgRepositoryDialog *dialog)
 {
 	if (!*new_text)
 	{
@@ -695,13 +902,19 @@ on_remote_name_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_tex
 	gchar *oldname;
 	gchar *url;
 
-	gtk_tree_model_get (GTK_TREE_MODEL (dialog->priv->list_store_remotes), 
+	gtk_tree_model_get (GTK_TREE_MODEL (dialog->priv->list_store_remotes),
 	                    &iter,
-	                    COLUMN_NAME, &oldname, 
+	                    COLUMN_NAME, &oldname,
 	                    COLUMN_URL, &url,
 	                    -1);
 
-	if (gitg_repository_commandv (dialog->priv->repository, NULL, "remote", "add", new_text, url, NULL))
+	if (gitg_shell_run_sync (gitg_command_new (dialog->priv->repository,
+	                                            "remote",
+	                                            "add",
+	                                            new_text,
+	                                            url,
+	                                            NULL),
+	                         NULL))
 	{
 		remove_remote (dialog, oldname);
 
@@ -720,7 +933,10 @@ on_remote_name_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_tex
 }
 
 void
-on_remote_url_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_text, GitgRepositoryDialog *dialog)
+on_remote_url_edited (GtkCellRendererText *renderer,
+                      gchar *path,
+                      gchar *new_text,
+                      GitgRepositoryDialog *dialog)
 {
 	if (!*new_text)
 	{
