@@ -718,6 +718,11 @@ gitg_repository_constructed (GObject *object)
 	}
 
 	install_head_monitor (repository);
+
+	if (G_OBJECT_CLASS (gitg_repository_parent_class)->constructed)
+	{
+		G_OBJECT_CLASS (gitg_repository_parent_class)->constructed (object);
+	}
 }
 
 static void
@@ -1300,6 +1305,7 @@ gitg_repository_init (GitgRepository *object)
 	                                            (GDestroyNotify)free_refs);
 
 	object->priv->loader = gitg_shell_new (10000);
+	gitg_io_set_auto_utf8 (GITG_IO (object->priv->loader), FALSE);
 
 	g_signal_connect (object->priv->loader,
 	                  "update",
